@@ -148,6 +148,19 @@ abi = [
         "stateMutability": "nonpayable",
         "type": "function"
     },
+    {
+        "inputs": [],
+        "name": "creditAddress",
+        "outputs": [
+            {
+                "internalType": "address",
+                "name": "",
+                "type": "address"
+            }
+        ],
+        "stateMutability": "view",
+        "type": "function"
+    },
     {
         "inputs": [
             {
@@ -327,7 +340,7 @@ abi = [
                 "type": "uint256"
             }
         ],
-        "name": "getCertificationByCertNum",
+        "name": "getCertificationByID",
         "outputs": [
             {
                 "components": [
@@ -427,6 +440,13 @@ abi = [
         "stateMutability": "view",
         "type": "function"
     },
+    {
+        "inputs": [],
+        "name": "initialize",
+        "outputs": [],
+        "stateMutability": "nonpayable",
+        "type": "function"
+    },
     {
         "inputs": [
             {
@@ -636,6 +656,8 @@ abi = [
     }
 ]
 
+DEFAULT_GAS_LIMIT = 2000000
+
 
 def add_certification(hash_str: str, cert_num: str, expire_date: int, version: str, desc: str, node_url: str,
                       address: str, contract_address: str, pk: str):
@@ -646,7 +668,7 @@ def add_certification(hash_str: str, cert_num: str, expire_date: int, version: s
     try:
         func = contract_instance.functions.addCertification(hash_str, cert_num, expire_date, version, desc)
         tx = func.buildTransaction(
-            {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce, 'gas': 2000000})
+            {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce, 'gas': DEFAULT_GAS_LIMIT})
         signed = client.eth.account.signTransaction(tx, pk)
         tx_hash = client.eth.sendRawTransaction(signed.rawTransaction)
         tx_res = client.eth.wait_for_transaction_receipt(tx_hash)
@@ -666,7 +688,7 @@ def revoke_certification(hash_str: str, revoker_name: str, node_url: str, contra
     try:
         func = contract_instance.functions.revoke(hash_str, revoker_name)
         tx = func.buildTransaction(
-            {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce})
+            {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce, 'gas': DEFAULT_GAS_LIMIT})
         signed = client.eth.account.signTransaction(tx, pk)
         tx_hash = client.eth.sendRawTransaction(signed.rawTransaction)
         tx_res = client.eth.wait_for_transaction_receipt(tx_hash)
@@ -689,7 +711,7 @@ def revoke_certification_by_id(cert_id: int, revoker_name: str, node_url: str, c
     try:
         func = contract_instance.functions.revokeById(cert_id, revoker_name)
         tx = func.buildTransaction(
-            {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce})
+            {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce, 'gas': DEFAULT_GAS_LIMIT})
         signed = client.eth.account.signTransaction(tx, pk)
         tx_hash = client.eth.sendRawTransaction(signed.rawTransaction)
         tx_res = client.eth.wait_for_transaction_receipt(tx_hash)
@@ -711,7 +733,7 @@ def charge_credit(address: str, credit: int, owner_address, owner_pk, node_url,
     try:
         func = contract_instance.functions.chargeCredit(client.toChecksumAddress(address), credit)
         tx = func.buildTransaction(
-            {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce})
+            {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce, 'gas': DEFAULT_GAS_LIMIT})
         signed = client.eth.account.signTransaction(tx, owner_pk)
         tx_hash = client.eth.sendRawTransaction(signed.rawTransaction)
         tx_res = client.eth.wait_for_transaction_receipt(tx_hash)
